Compare groups for each item with multiple target items by calculating F-statistics and effect sizes
Source:R/effects.R
effect_metrics_items_grouped_items.RdNot yet implemented. The future will come.
Arguments
- data
A tibble containing item measures.
- cols
Tidyselect item variables (e.g. starts_with...).
- cross
The grouping items.
- clean
Prepare data by data_clean.
- ...
Placeholder to allow calling the method with unused parameters from effect_counts.