Convert numeric values to factors, characters or logical values while preserving attributes
Source:R/clean.R
data_cat.RdConvert numeric values to factors, characters or logical values while preserving attributes

R/clean.R
data_cat.RdConvert numeric values to factors, characters or logical values while preserving attributes